@@ -38,7 +38,7 @@ bootstrap.pml = function (x, bs = 100, trees = TRUE, multicore=FALSE, mc.cores =
 }
 
 
-bootstrap.phyDat <- function (x, FUN, bs = 100, multicore=FALSE, mc.cores = NULL, ...) 
+bootstrap.phyDat <- function (x, FUN, bs = 100, multicore=FALSE, mc.cores = NULL, jumble=TRUE, ...) 
 {
     if(multicore && is.null(mc.cores)){
         mc.cores <- detectCores()
@@ -47,14 +47,32 @@ bootstrap.phyDat <- function (x, FUN, bs = 100, multicore=FALSE, mc.cores = NULL
     v = rep(1:length(weight), weight)
     BS = vector("list", bs)
     for(i in 1:bs)BS[[i]]=tabulate(sample(v, replace=TRUE),length(weight)) 
+    if(jumble){
+        J = vector("list", bs)
+        l = length(x)
+        for(i in 1:bs) J[[i]] = list(BS[[i]], sample(l))
+    }
     fitPar <- function(weights, data, ...){     
         ind <- which(weights > 0)
         data <- getRows(data, ind)
         attr(data, "weight") <- weights[ind]
         FUN(data,...)        
     }
-    if(multicore) res <- mclapply(BS, fitPar, x, ..., mc.cores = mc.cores) 
-    else res <- lapply(BS, fitPar, x, ...)
+    fitParJumble <- function(J, data, ...){     
+        ind <- which(J[[1]] > 0)
+        data <- getRows(data, ind)
+        attr(data, "weight") <- J[[1]][ind]
+        data <- subset(data, J[[2]])
+        FUN(data,...)        
+    }
+    if(multicore){
+        if(jumble) res <- mclapply(J, fitPar, x, ..., mc.cores = mc.cores) 
+        else res <- mclapply(BS, fitPar, x, ..., mc.cores = mc.cores) 
+    }        
+    else{
+        if(jumble) res <- lapply(J, fitParJumble, x, ...) 
+        else res <- lapply(BS, fitPar, x, ...)
+    } 
     if(class(res[[1]]) == "phylo"){
         class(res) <- "multiPhylo"   
         res = .compressTipLabel(res) # save memory
@@ -66,7 +84,7 @@ bootstrap.phyDat <- function (x, FUN, bs = 100, multicore=FALSE, mc.cores = NULL
 matchEdges = function(tree1, tree2){
     bp1 = bip(tree1)
     bp2 = bip(tree2)
-    l = length(tree1$tip)
+    l = length(tree1$tip.label)
     fn = function(x, y){
         if(x[1]==1)return(x)
         else return(y[-x])
@@ -116,12 +134,12 @@ plotBS <- function (tree, BStrees, type = "unrooted", bs.col = "black",
         x <- tree$node.label
     }
     
-    label = c(rep(0, length(tree$tip)), x)
+    label = c(rep(0, length(tree$tip.label)), x)
     ind <- get("last_plot.phylo", envir = .PlotPhyloEnv)$edge[, 
                                                               2]
     if (type == "phylogram" | type == "cladogram") {
         root = getRoot(tree)
-        label = c(rep(0, length(tree$tip)), x)
+        label = c(rep(0, length(tree$tip.label)), x)
         label[root] = 0
         ind2 = matchEdges(tree2, tree)
         label = label[ind2]
@@ -143,76 +161,6 @@ plotBS <- function (tree, BStrees, type = "unrooted", bs.col = "black",
 }
 
 
-plotBS.Old <- function (tree, BStrees, type = "unrooted", bs.col = "black", 
-                        bs.adj = NULL, p=80, ...) 
-{
-    # prop.clades raus??
-    prop.clades <- function(phy, ..., part = NULL, rooted = FALSE) {
-        if (is.null(part)) {
-            obj <- list(...)
-            if (length(obj) == 1 && class(obj[[1]]) != "phylo") 
-                obj <- unlist(obj, recursive = FALSE)
-            if (!identical(phy$tip, obj[[1]]$tip)) 
-                obj[[1]] = checkLabels(obj[[1]], phy$tip)
-            part <- prop.part(obj, check.labels = TRUE)
-        }
-        bp <- prop.part(phy)
-        if (!rooted) {
-            bp <- postprocess.prop.part(bp)
-            part <- postprocess.prop.part(part)
-        }
-        n <- numeric(phy$Nnode)
-        for (i in seq_along(bp)) {
-            for (j in seq_along(part)) {
-                if (identical(bp[[i]], part[[j]])) {
-                    n[i] <- attr(part, "number")[j]
-                    done <- TRUE
-                    break
-                }
-            }
-        }
-        n
-    }
-    type <- match.arg(type, c("phylogram", "cladogram", "fan", 
-                              "unrooted", "radial"))
-    if (type == "phylogram" | type == "cladogram") {
-        if (!is.rooted(tree) & !is.null(tree$edge.length)) 
-            tree2 = midpoint(tree)
-        else tree2=tree
-        plot(tree2, type = type, ...)
-    }
-    else plot(tree, type = type, ...)
-    BStrees <- .uncompressTipLabel(BStrees)
-    x = prop.clades(tree, BStrees)
-    x = round((x/length(BStrees)) * 100)
-    tree$node.label = x
-    label = c(rep(0, length(tree$tip)), x)
-    ind <- get("last_plot.phylo", envir = .PlotPhyloEnv)$edge[, 
-                                                              2]
-    if (type == "phylogram" | type == "cladogram") {
-        root = getRoot(tree)
-        label = c(rep(0, length(tree$tip)), x)
-        label[root] = 0
-        ind2 = matchEdges(tree2, tree)
-        label = label[ind2]
-        ind = which(label > p)
-        #        browser()
-        if (is.null(bs.adj)) 
-            bs.adj = c(1, 1)
-        if(length(ind)>0)nodelabels(text = label[ind], node = ind, frame = "none", 
-                                    col = bs.col, adj = bs.adj, ...)
-    }
-    else {
-        if (is.null(bs.adj)) 
-            bs.adj = c(0.5, 0.5)
-        ind2 = which(label[ind]>p)
-        if(length(ind2>0))edgelabels(label[ind][ind2],ind2, frame = "none", col = bs.col, 
-                                     adj = bs.adj, ...)
-    }
-    invisible(tree)
-}
-
-
 maxCladeCred <- function(x, tree=TRUE, part=NULL, rooted=TRUE){
     if(inherits(x, "phylo")) x <- c(x)
     if(!rooted){
