@@ -2,17 +2,6 @@
 # tree manipulation
 # 
 
-# from coalescenMCMC
-getIndexEdge <- function(tip, edge)
-    ## 'integer(1)' mustn't be substituted by '0L' except if 'DUP = TRUE':
-    .C("get_single_index_integer", as.integer(edge[, 2L]),
-       as.integer(tip), integer(1L), PACKAGE = "phangorn",
-       NAOK = TRUE)[[3L]]
-
-getIndexEdge2 <- function(node, edge)
-    .C("get_two_index_integer", as.integer(edge[, 1L]),
-       as.integer(node), integer(2L), PACKAGE = "phangorn",
-       NAOK = TRUE)[[3L]]
 
 # no checks for postorder
 getRoot <- function (tree) 
@@ -98,11 +87,10 @@ node2root <- function(x){
 }
     oldtree <- tree
     tree = unroot(tree)   
-    nTips = length(tree$tip)
+    nTips = length(tree$tip.label)
     maxD1 = node2root(tree)[1:nTips] 
     ind = which.max(maxD1)
     tmproot = Ancestors(tree, ind, "parent")
-#    tree = reroot(tree, tmproot)
     nTips  = length(tree$tip.label)
     if(tmproot>nTips) tree = root(tree, node=tmproot)
     else  tree = root(tree, tmproot)   
@@ -167,7 +155,7 @@ pruneTree = function(tree, ..., FUN = ">="){
      if(is.null(tree$node)) stop("no node labels")
      if(is.rooted(tree)) tree = unroot(tree)
      m = max(tree$edge)
-     nTips = length(tree$tip)
+     nTips = length(tree$tip.label)
      bs = rep(TRUE, m)
      bs[ (nTips+1) : m] = sapply(as.numeric(as.character(tree$node)), FUN,...)    
      tree$edge.length[!bs[tree$edge[,2]]] = 0
@@ -182,8 +170,6 @@ pruneTree = function(tree, ..., FUN = ">="){
 # pos statt i      
 dropTip <- function(x, i, check.binary=FALSE, check.root=TRUE){
     edge <- x$edge
-#    edge1 <- edge[,1]
-#    edge2 <- edge[,2]
     root <- getRoot(x)
     ch <- which(edge[,2] == i)
     pa <- edge[ch,1] 
@@ -222,46 +208,6 @@ dropTip <- function(x, i, check.binary=FALSE, check.root=TRUE){
     x
 }
 
-# kind of works well too
-dropTip2 <- function(x, i, check.binary=FALSE, check.root=TRUE){
-  edge <- x$edge
-  root <- getRoot(x)
-  ch <- which(edge[,2] == i)
-  pa <- edge[ch,1] 
-  edge = edge[-ch,]
-  ind <- which(edge[,1] == pa) 
-  if(root == pa){
-    if(length(ind)==1){
-      edge = edge[-ind,]
-      x$Nnode=x$Nnode-1L
-    }
-    if(length(ind)==2){
-      n = dim(edge)[1]
-      newroot = edge[n-2L,1]
-      newedge = edge[ind,2] 
-      if(newedge[1]==newroot)edge[n-1,] <- newedge
-      else edge[n-1,] <- newedge[2:1]
-      edge = edge[-n,]   
-      x$Nnode=x$Nnode-1L
-      edge[edge==newroot] = root
-      pa <- newroot
-    }
-    # todo handle unrooted trees  
-  }
-  else{
-    nind <- which(edge[,2] == pa)         
-    # normal binary case
-    if(length(ind)==1){
-      edge[nind,2] = edge[ind,2]
-      edge <- edge[-ind,]
-      x$Nnode <- x$Nnode-1L           
-    }  
-  }
-  #
-#  edge[edge>pa]  = edge[edge>pa] -1L 
-  x$edge <- edge
-  x
-}
 
 
 # like drop tip and returns two trees, 
@@ -343,114 +289,6 @@ dropNode <- function(x, i, check.binary=FALSE, check.root=TRUE, all.ch=NULL){
 }
 
 
-
-dropNodeNew <- function(edge, i, nTips, check.binary=FALSE, check.root=TRUE){
-    root <- edge[nrow(edge),2]
-    ch <- which(edge[,2] == i)
-    pa <- edge[ch,1]
-    edge2=NULL
-    
-    # einfachere allChildren Variante 2*schneller
-    allKids = function (edge, nTips) 
-    {
-        parent = edge[, 1]
-        children = edge[, 2]
-        .Call("AllChildren", as.integer(children), as.integer(parent), as.integer(max(edge)), PACKAGE = "phangorn")
-    }
-    
-    descAll = function (edge, node, nTips) 
-    {
-        ch = allKids(edge, nTips)
-        isInternal = logical(max(edge))
-        isInternal[unique(edge[, 1])] = TRUE
-        desc = function(node, isInternal) {
-            if (!isInternal[node]) return(node)
-            res = NULL
-            while (length(node) > 0) {
-                tmp = unlist(ch[node])
-                res = c(res, tmp)
-                node = tmp[isInternal[tmp]]
-            }
-            res
-        }
-        desc(node, isInternal)
-    }    
-    
-    if(i>nTips){
-        kids <- descAll(edge, i, nTips)
-        ind <- match(kids,edge[,2])
-        edge2 <- edge[sort(ind),]            
-        edge <- edge[-c(ch, ind),]
-    }    
-    else edge = edge[-ch,]
-    if(nrow(edge)<3)return(NULL)  
-    ind <- which(edge[,1] == pa) 
-    if(root == pa){
-        if(length(ind)==1){
-            edge = edge[-ind,]
-        }
-        if(length(ind)==2){
-            n = dim(edge)[1]
-            newroot = edge[n-2L,1]
-            newedge = edge[ind,2] 
-            if(newedge[1]==newroot)edge[n-1,] <- newedge
-            else edge[n-1,] <- newedge[2:1]
-            edge = edge[-n,]   
-            edge[edge==newroot] = root
-            pa <- newroot
-        }
-        # todo handle unrooted trees  
-    }
-    else{
-        nind <- which(edge[,2] == pa)         
-        # normal binary case
-        if(length(ind)==1){
-            edge[nind,2] = edge[ind,2]
-            edge <- edge[-ind,]          
-        }  
-    }
-    #
-    #  edge[edge>pa]  = edge[edge>pa] -1L 
-    list(edge, edge2, pa)
-}
-
-
-dropTipNew <- function(edge, i, nTips, check.binary=FALSE, check.root=TRUE){
-    root <- edge[nrow(edge),2]
-    ch <- which(edge[,2] == i)
-    pa <- edge[ch,1] 
-    edge = edge[-ch,]
-    ind <- which(edge[,1] == pa) 
-    if(root == pa){
-        if(length(ind)==1){
-            edge = edge[-ind,]
-        }
-        if(length(ind)==2){
-            n = dim(edge)[1]
-            newroot = edge[n-2L,1]
-            newedge = edge[ind,2] 
-            if(newedge[1]==newroot)edge[n-1,] <- newedge
-            else edge[n-1,] <- newedge[2:1]
-            edge = edge[-n,]   
-            edge[edge==newroot] = root
-            pa <- newroot
-        }
-        # todo handle unrooted trees  
-    }
-    else{
-        nind <- which(edge[,2] == pa)         
-        # normal binary case
-        if(length(ind)==1){
-            edge[nind,2] = edge[ind,2]
-            edge <- edge[-ind,]       
-        }  
-    }
-    #
-    edge[edge>pa]  = edge[edge>pa] -1L 
-    edge
-}
-
-
 # postorder remained tip in 1:nTips
 addOne <- function (tree, tip, i){
     edge = tree$edge
@@ -485,7 +323,7 @@ addOneTree <- function (tree, subtree, i, node){
   tree$edge = edge 
   tree$Nnode = tree$Nnode + subtree$Nnode + 1L
   attr(tree, "order") = NULL
-  tips1 = as.integer(length(tree$tip) + 1L)
+  tips1 = as.integer(length(tree$tip.label) + 1L)
   tmproot = getRoot(tree)
   if(tmproot!=tips1){
       tree$edge[tree$edge==tmproot] = 0L
@@ -673,44 +511,6 @@ allTrees <- function (n, rooted = FALSE, tip.label = NULL)
 }
 
 
-
-dn <- function (x){
-    if (!is.binary.tree(x) ) 
-        x <- multi2di(x, random = FALSE)  
-    x = reroot2(x, 1)       
-    n <- length(x$tip.label)
-    n.node <- x$Nnode
-    N <- n + n.node
-    x <- reorderPruning(x)
-    res <- matrix(NA, N, N)
-    res[cbind(1:N, 1:N)] <- 0
-    res[x$edge] <- res[x$edge[, 2:1]] <- 1
-    for (i in seq(from = 1, by = 2, length.out = n.node)) {
-        j <- i + 1
-        anc <- x$edge[i, 1]
-        des1 <- x$edge[i, 2]
-        des2 <- x$edge[j, 2]
-        if (des1 > n) 
-            des1 <- which(!is.na(res[des1, ]))
-        if (des2 > n) 
-            des2 <- which(!is.na(res[des2, ]))
-        for (y in des1) res[y, des2] <- res[des2, y] <- res[anc, 
-            y] + res[anc, des2]
-        if (anc != 1) {
-            ind <- which(x$edge[, 2] == anc)
-            nod <- x$edge[ind, 1]
-            l <- length(ind)
-            res[des2, nod] <- res[nod, des2] <- res[anc, des2] + 
-                l
-            res[des1, nod] <- res[nod, des1] <- res[anc, des1] + 
-                l
-        }
-    }
-    dimnames(res)[1:2] <- list(1:N)
-    res
-}
-
-
 # replace with dist.nodes
 dn <- function(x){
 #  if (!is.binary.tree(x) ) x <- multi2di(x, random = FALSE)
@@ -839,7 +639,7 @@ sprMove <- function(tree, m){
 
     edge = tree$edge    
     k = max(edge)
-    nTips = length(tree$tip)
+    nTips = length(tree$tip.label)
     nEdges = 2*nTips-3 
     if(m > nEdges) stop("m to big")
 
@@ -995,7 +795,7 @@ Ancestors <- function (x, node, type = c("all", "parent"))
 
 
 allChildren <- function(x){
-   l = length(x$tip) 
+   l = length(x$tip.label) 
    if(l<20){
        parent = x$edge[,1]
        children = x$edge[,2]
@@ -1112,26 +912,6 @@ mrca2 <- function(phy, full=FALSE){
 # mrca.phylo <- getMRCA
 
 
-# 1090
-rNNI_Old <- function(tree, moves=1, n=1){   
-    k = length(na.omit(match(tree$edge[,2], tree$edge[,1])))   
-    if(n==1){
-        trees = tree
-        for(i in 1:moves) trees = nnin(trees,sample(k,1))[[sample(2,1)]] 
-        trees$tip.label <- tree$tip.label
-    }  
-    else{
-        trees = vector("list", n)
-        for(j in 1:n){
-            tmp = tree 
-            for(i in 1:moves) tmp = nnin(tmp, sample(k,1))[[sample(2,1)]]
-            tmp$tip.label=NULL
-            trees[[j]] = tmp
-        }
-        attr(trees, "TipLabel") <- tree$tip.label
-        class(trees) <- "multiPhylo"   
-    }
-    trees
-}
+
 
 
