@@ -1,7 +1,7 @@
 /* 
  * dist.c
  *
- * (c) 2008-2015  Klaus Schliep (klaus.schliep@gmail.com)
+ * (c) 2008-2016  Klaus Schliep (klaus.schliep@gmail.com)
  * 
  * 
  * This code may be distributed under the GNU GPL
@@ -49,7 +49,7 @@ void rowMin2(double *dat, int n,  int k, double *res){
     }
 
    
-void rowMinInt(int *dat, int n,  int k, double *res){
+void rowMinInt(int *dat, int n,  int k, int *res){
     int i, h;  
     int x;
     for(i = 0; i < n; i++){
